@@ -84,9 +84,10 @@ void GameArea::Layout()
   Lum::Control::Layout();
 }
 
-void GameArea::Draw(int x, int y, size_t w, size_t h)
+void GameArea::Draw(Lum::OS::DrawInfo* draw,
+                    int x, int y, size_t w, size_t h)
 {
-  Lum::Control::Draw(x,y,w,h);
+  Lum::Control::Draw(draw,x,y,w,h);
 
   if (!OIntersect(x,y,w,h)) {
     return;
@@ -94,8 +95,6 @@ void GameArea::Draw(int x, int y, size_t w, size_t h)
 
   /* --- */
 
-  Lum::OS::DrawInfo *draw=GetDrawInfo();
-
   if (factor->IsNull()) {
     return;
   }
